from cwtags.tagbuilder import tag

a = tag('a')
abbr = tag('abbr')
address = tag('address')
area = tag('area')
article = tag('article') # html5
aside = tag('aside') # html5
audio = tag('audio') # html5

b = tag('b')
base = tag('base')
bdi = tag('bdi') # html5
bdo = tag('bdo') # html5
big = tag('big') # html4 only
blockquote = tag('blockquote')
body = tag('body')
br = tag('br')
button = tag('button')

canvas = tag('canvas')
caption = tag('caption')
center = tag('center') # html4 only
cite = tag('cite')
code = tag('code')
col = tag('col')
colgroup = tag('colgroup')
command = tag('command') # html5
datalist = tag('datalist') # html5
dd = tag('dd')
# del

details = tag('details') # html5
dfn = tag('dfn')
dialog = tag('dialog')
div = tag('div')
dl = tag('dl')
dt = tag('dt')
em = tag('em')
embed = tag('embed') # html5
fieldset = tag('fieldset')
figcaption = tag('figcaption')
figure = tag('figure')
footer = tag('footer') # html5
form = tag('form')
frame = tag('frame') # html4 only
frameset = tag('frameset') # html4 only

h1 = tag('h1')
h2 = tag('h2')
h3 = tag('h3')
h4 = tag('h4')
h5 = tag('h5')
h6 = tag('h6')
head = tag('head')
header = tag('header') # html5
hgroup = tag('hgroup') # html5
hr = tag('hr')
html = tag('html')

i = tag('i')
iframe = tag('iframe')
img = tag('img')
input = tag('input')
ins = tag('ins')

kbd = tag('kbd')
keygen = tag('keygen') # html5

label = tag('label')
legend = tag('legend')
li = tag('li')
link = tag('link')

map = tag('map')
mark = tag('mark') # html5
menu = tag('menu')
meta = tag('meta')
meter = tag('meter') # html5

nav = tag('nav') # html5
noframes = tag('noframes') # html4 only
noscript = tag('noscript')

object = tag('object')
ol = tag('ol')
optgroup = tag('optgroup')
option = tag('option')
output = tag('output') # html5

p = tag('p')
param = tag('param')
pre = tag('pre')
progress = tag('progress') # html5

q = tag('q')
rp = tag('rp') # html5
rt = tag('rt') # html5
ruby = tag('ruby') # html5

s = tag('s')
samp = tag('samp')
script = tag('script')
section = tag('section') # html5
select = tag('select')
small = tag('small')
source = tag('source') # html5
span = tag('span')
strong = tag('strong')
style = tag('style')
sub = tag('sub')
summary = tag('summary') # html5
sup = tag('sup')

table = tag('table')
tbody = tag('tbody')
td = tag('td')
textarea = tag('textarea')
tfoot = tag('tfoot')
th = tag('th')
thead = tag('thead')
time = tag('time') # html5
title = tag('title')
tr = tag('tr')
track = tag('track')
tt = tag('tt') # html4 only

u = tag('u')
ul = tag('ul')

var = tag('var')
video = tag('video') # html5
wbr = tag('wbr')
